smartcard.reader.ReaderGroups.readergroups

# ``smartcard`.`reader`.`ReaderGroups`.`readergroups``

class documentation

`class readergroups(object):`

Known subclasses: `smartcard.pcsc.PCSCReaderGroups.PCSCReaderGroups`

View In Hierarchy

ReadersGroups organizes smart card reader as groups.

Method | `__getattr__` | Undocumented
Method | `__init__` | Create a single instance of innerreadergroups on first call
Class Variable | `instance` | Undocumented

def __getattr__(self, name):

Undocumented

def __init__(self, initlist=None):
overridden in `smartcard.pcsc.PCSCReaderGroups.PCSCReaderGroups`

Create a single instance of innerreadergroups on first call

instance =

Undocumented